@@ -35,7 +35,7 @@ def trace(f):
     """
     return decorator(_trace, f)
 
-def trace2(f,out_level=VERBOSE)
+def trace2(f,out_level=VERBOSE):
     """
     Same as :function:`trace` but more verbose.
     :param f: the function
